@@ -12,13 +12,15 @@ from starlette.testclient import TestClient
 from justpy.routing import JpRoute
 from tests.basetest import Basetest
 
-@jp.SetRoute('/greet/{name}')
+
+@jp.SetRoute("/greet/{name}")
 def greeting_function(request):
     wp = jp.WebPage()
-    name=f"""{request.path_params["name"]}"""
-    wp.add(jp.P(text=f'Hello there, {name}!', classes='text-5xl m-2'))
+    name = f"""{request.path_params["name"]}"""
+    wp.add(jp.P(text=f"Hello there, {name}!", classes="text-5xl m-2"))
     return wp
 
+
 @jp.SetRoute("/bye", name="bye")
 def bye_function(_request):
     wp = jp.WebPage()
@@ -38,10 +40,10 @@ class TestRouteAndUrlFor(Basetest):
     """
     test the url_for functionality
     """
-    
+
     def setUp(self, debug=False, profile=True):
         Basetest.setUp(self, debug=debug, profile=profile)
-        self.app=jp.app
+        self.app = jp.app
 
     def testRoute(self):
         """
@@ -54,20 +56,20 @@ class TestRouteAndUrlFor(Basetest):
             route_as_text = str(route)
             if debug:
                 print(route_as_text)
-        for path in ["/bye", "/hello","/greet/{name}"]:
+        for path in ["/bye", "/hello", "/greet/{name}"]:
             self.assertTrue(path in JpRoute.routes_by_path)
-            
-    def checkResponse(self,path,expected_code=200,debug:bool=None):
+
+    def checkResponse(self, path, expected_code=200, debug: bool = None):
         """
         check the response for the given path
-        
+
         Args:
             path(str): the path to check
             expected_code(int): the HTTP status code to expect
             debug(bool): if True show debugging info
         """
         if debug is None:
-            debug=self.debug
+            debug = self.debug
         with TestClient(self.app) as client:
             response = client.get(path)
             self.assertEqual(expected_code, response.status_code)
@@ -79,27 +81,27 @@ class TestRouteAndUrlFor(Basetest):
         """
         Test url for functionality
         """
-        #@TODO - not implemented yet
+        # @TODO - not implemented yet
         pass
-    
+
     def testInvalidPath(self):
-        '''
+        """
         test handling an invalid path
-        '''
-        response=self.checkResponse("/invalidpath",404)
-        self.assertEqual(jp.HTML_404_PAGE,response.text)
-        
+        """
+        response = self.checkResponse("/invalidpath", 404)
+        self.assertEqual(jp.HTML_404_PAGE, response.text)
+
     def testStaticPath(self):
-        '''
+        """
         test handling static content
-        '''
-        response=self.checkResponse("/templates/js/justpy_core.js")        
+        """
+        response = self.checkResponse("/templates/js/justpy_core.js")
         self.assertTrue("class JustpyCore" in response.text)
-        response=self.checkResponse("/templates/css/invalid_css.css",404)
-    
+        response = self.checkResponse("/templates/css/invalid_css.css", 404)
+
     def testHtmlContent(self):
         # see https://www.starlette.io/testclient/
-        response=self.checkResponse("/hello")
+        response = self.checkResponse("/hello")
         debug = self.debug
         debug = True
         lines = response.text.split("\n")
